# score: 100
from collections import deque

def toposort(g):
    # Kahn's algorithm to avoid recursion
    n = len(g)
    indeg = [0]*n
    order = []
    for v in range(n):
        for w, _ in g[v]:
            indeg[w] += 1
    q = []
    for v in range(n):
        if indeg[v] == 0:
            q.append(v)
    while q:
        v = q.pop()
        order.append(v)
        for w, c in g[v]:
            indeg[w] -= 1
            if indeg[w] == 0:
                q.append(w)
    assert all(x==0 for x in indeg)
    assert len(order)==n
    return order

def read_graph(n, m, factor):
    g=[[] for _ in range(n)]
    for i in range(m):
        s=input()
        a, b, w = map(int, s.split())
        g[a].append((b, factor*w))
    return g

def shortest_path_in_dag(g, order, start):
    n = len(g)
    dist = [None]*n
    dist[start] = 0
    for v in order:
        if dist[v] is None:
            continue
        for w, c in g[v]:
            d = dist[v] + c
            if dist[w] is None or dist[w] > d:
                dist[w] = d
    return dist

n, m0, m1 = map(int, input().split())
dists = []
for m, factor in ((m0, 1), (m1, -1)):
    g = read_graph(n, m, factor)
    order = toposort(g)
    dists.append([shortest_path_in_dag(g, order, v) for v in range(n)])

best = None
for i in range(n):
    for j in range(n):
        if i != j:
            a = dists[0][i][j]
            b = dists[1][j][i]
            if a is None or b is None:
                continue
            b = -b
            if best is None:
                best = (i, j, a, b)
                continue
            xi, xj, xa, xb = best
            if a*xb < xa*b:
                best = (i, j, a, b)
if best is None:
    print(best)
else:
    print(*best)
